Enum pallet_democracy::pallet::Event [−][src]
pub enum Event<T: Config> {
Show 17 variants
Proposed {
proposal_index: PropIndex,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
},
Tabled {
proposal_index: PropIndex,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
depositors: Vec<T::AccountId>,
},
ExternalTabled,
Started {
ref_index: ReferendumIndex,
threshold: VoteThreshold,
},
Passed {
ref_index: ReferendumIndex,
},
NotPassed {
ref_index: ReferendumIndex,
},
Cancelled {
ref_index: ReferendumIndex,
},
Executed {
ref_index: ReferendumIndex,
result: DispatchResult,
},
Delegated {
who: T::AccountId,
target: T::AccountId,
},
Undelegated {
account: T::AccountId,
},
Vetoed {
who: T::AccountId,
proposal_hash: T::Hash,
until: T::BlockNumber,
},
PreimageNoted {
proposal_hash: T::Hash,
who: T::AccountId,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
},
PreimageUsed {
proposal_hash: T::Hash,
provider: T::AccountId,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
},
PreimageInvalid {
proposal_hash: T::Hash,
ref_index: ReferendumIndex,
},
PreimageMissing {
proposal_hash: T::Hash,
ref_index: ReferendumIndex,
},
PreimageReaped {
proposal_hash: T::Hash,
provider: T::AccountId,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
reaper: T::AccountId,
},
Blacklisted {
proposal_hash: T::Hash,
},
// some variants omitted
}Expand description
The event emitted by this pallet.
Variants
A motion has been proposed by a public account.
Fields of Proposed
A public proposal has been tabled for referendum vote.
Fields of Tabled
An external proposal has been tabled.
A referendum has begun.
Fields of Started
ref_index: ReferendumIndexthreshold: VoteThresholdA proposal has been approved by referendum.
Fields of Passed
ref_index: ReferendumIndexA proposal has been rejected by referendum.
Fields of NotPassed
ref_index: ReferendumIndexA referendum has been cancelled.
Fields of Cancelled
ref_index: ReferendumIndexA proposal has been enacted.
Fields of Executed
ref_index: ReferendumIndexresult: DispatchResultAn account has delegated their vote to another account.
An account has cancelled a previous delegation operation.
Fields of Undelegated
account: T::AccountIdAn external proposal has been vetoed.
Fields of Vetoed
A proposal’s preimage was noted, and the deposit taken.
Fields of PreimageNoted
A proposal preimage was removed and used (the deposit was returned).
Fields of PreimageUsed
A proposal could not be executed because its preimage was invalid.
Fields of PreimageInvalid
proposal_hash: T::Hashref_index: ReferendumIndexA proposal could not be executed because its preimage was missing.
Fields of PreimageMissing
proposal_hash: T::Hashref_index: ReferendumIndexA registered preimage was removed and the deposit collected by the reaper.
Fields of PreimageReaped
A proposal_hash has been blacklisted permanently.
Fields of Blacklisted
proposal_hash: T::HashTrait Implementations
impl<T: Config> Decode for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
Vec<T::AccountId>: Decode,
Vec<T::AccountId>: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::BlockNumber: Decode,
T::BlockNumber: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::Hash: Decode,
T::Hash: Decode,
impl<T: Config> Decode for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
Vec<T::AccountId>: Decode,
Vec<T::AccountId>: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::BlockNumber: Decode,
T::BlockNumber: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::Hash: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Decode,
T::AccountId: Decode,
T::AccountId: Decode,
T::Hash: Decode,
T::Hash: Decode,
impl<T: Config> Encode for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
Vec<T::AccountId>: Encode,
Vec<T::AccountId>: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::BlockNumber: Encode,
T::BlockNumber: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::Hash: Encode,
T::Hash: Encode,
impl<T: Config> Encode for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
Vec<T::AccountId>: Encode,
Vec<T::AccountId>: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::BlockNumber: Encode,
T::BlockNumber: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::Hash: Encode,
T::Hash: Encode,
impl<T: Config> TypeInfo for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
Vec<T::AccountId>: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::BlockNumber: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
PhantomData<T>: TypeInfo + 'static,
T: Config + 'static,
impl<T: Config> TypeInfo for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
Vec<T::AccountId>: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::BlockNumber: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: TypeInfo + 'static,
T::AccountId: TypeInfo + 'static,
T::Hash: TypeInfo + 'static,
PhantomData<T>: TypeInfo + 'static,
T: Config + 'static,
impl<T: Config> EncodeLike<Event<T>> for Event<T> where
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
Vec<T::AccountId>: Encode,
Vec<T::AccountId>: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::BlockNumber: Encode,
T::BlockNumber: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::Hash: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance: Encode,
T::AccountId: Encode,
T::AccountId: Encode,
T::Hash: Encode,
T::Hash: Encode,